/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /builds/slave/m-cen-lx-xr-ntly-0000000000000/build/dom/plugins/base/nspluginroot.idl
 */

#ifndef __gen_nspluginroot_h__
#define __gen_nspluginroot_h__

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

#endif /* __gen_nspluginroot_h__ */
